@@ -1,5 +1,5 @@
 # -*- coding: utf8 -*-
-# Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
+# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -13,6 +13,8 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+import warnings
+
 from tencentcloud.common.abstract_model import AbstractModel
 
 
@@ -59,6 +61,13 @@ class CreateAudioDepositRequest(AbstractModel):
         self.FileUrl = params.get("FileUrl")
         self.HashType = params.get("HashType")
         self.EvidenceDescription = params.get("EvidenceDescription")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class CreateAudioDepositResponse(AbstractModel):
@@ -122,6 +131,13 @@ class CreateDataDepositRequest(AbstractModel):
         self.BusinessId = params.get("BusinessId")
         self.HashType = params.get("HashType")
         self.EvidenceDescription = params.get("EvidenceDescription")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class CreateDataDepositResponse(AbstractModel):
@@ -193,6 +209,13 @@ class CreateDocDepositRequest(AbstractModel):
         self.FileUrl = params.get("FileUrl")
         self.HashType = params.get("HashType")
         self.EvidenceDescription = params.get("EvidenceDescription")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class CreateDocDepositResponse(AbstractModel):
@@ -248,6 +271,13 @@ class CreateHashDepositNoCertRequest(AbstractModel):
         self.BusinessId = params.get("BusinessId")
         self.HashType = params.get("HashType")
         self.EvidenceInfo = params.get("EvidenceInfo")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class CreateHashDepositNoCertResponse(AbstractModel):
@@ -315,6 +345,13 @@ class CreateHashDepositNoSealRequest(AbstractModel):
         self.BusinessId = params.get("BusinessId")
         self.HashType = params.get("HashType")
         self.EvidenceInfo = params.get("EvidenceInfo")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class CreateHashDepositNoSealResponse(AbstractModel):
@@ -386,6 +423,13 @@ class CreateHashDepositRequest(AbstractModel):
         self.BusinessId = params.get("BusinessId")
         self.HashType = params.get("HashType")
         self.EvidenceDescription = params.get("EvidenceDescription")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class CreateHashDepositResponse(AbstractModel):
@@ -457,6 +501,13 @@ class CreateImageDepositRequest(AbstractModel):
         self.FileUrl = params.get("FileUrl")
         self.HashType = params.get("HashType")
         self.EvidenceDescription = params.get("EvidenceDescription")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class CreateImageDepositResponse(AbstractModel):
@@ -528,6 +579,13 @@ class CreateVideoDepositRequest(AbstractModel):
         self.FileUrl = params.get("FileUrl")
         self.HashType = params.get("HashType")
         self.EvidenceDescription = params.get("EvidenceDescription")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class CreateVideoDepositResponse(AbstractModel):
@@ -587,6 +645,13 @@ class CreateWebpageDepositRequest(AbstractModel):
         self.BusinessId = params.get("BusinessId")
         self.HashType = params.get("HashType")
         self.EvidenceDescription = params.get("EvidenceDescription")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class CreateWebpageDepositResponse(AbstractModel):
@@ -630,6 +695,13 @@ class GetDepositCertRequest(AbstractModel):
 
     def _deserialize(self, params):
         self.EvidenceId = params.get("EvidenceId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class GetDepositCertResponse(AbstractModel):
@@ -672,6 +744,13 @@ class GetDepositFileRequest(AbstractModel):
 
     def _deserialize(self, params):
         self.EvidenceId = params.get("EvidenceId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class GetDepositFileResponse(AbstractModel):
@@ -714,6 +793,13 @@ class GetDepositInfoRequest(AbstractModel):
 
     def _deserialize(self, params):
         self.EvidenceId = params.get("EvidenceId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class GetDepositInfoResponse(AbstractModel):
