@@ -1,5 +1,5 @@
 # -*- coding: utf8 -*-
-# Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
+# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -138,6 +138,34 @@ class CdnClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def CreateScdnDomain(self, request):
+        """CreateScdnDomain 用于创建 SCDN 加速域名
+
+        :param request: Request instance for CreateScdnDomain.
+        :type request: :class:`tencentcloud.cdn.v20180606.models.CreateScdnDomainRequest`
+        :rtype: :class:`tencentcloud.cdn.v20180606.models.CreateScdnDomainResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("CreateScdnDomain", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.CreateScdnDomainResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def CreateScdnFailedLogTask(self, request):
         """CreateScdnFailedLogTask 用于重试创建失败的事件日志任务
 
