@@ -1,5 +1,5 @@
 # -*- coding: utf8 -*-
-# Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
+# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -13,6 +13,8 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+import warnings
+
 from tencentcloud.common.abstract_model import AbstractModel
 
 
@@ -35,6 +37,13 @@ class Attachment(AbstractModel):
     def _deserialize(self, params):
         self.FileName = params.get("FileName")
         self.Content = params.get("Content")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class BlackEmailAddress(AbstractModel):
@@ -56,6 +65,13 @@ class BlackEmailAddress(AbstractModel):
     def _deserialize(self, params):
         self.BounceTime = params.get("BounceTime")
         self.EmailAddress = params.get("EmailAddress")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class CreateEmailAddressRequest(AbstractModel):
@@ -77,6 +93,13 @@ class CreateEmailAddressRequest(AbstractModel):
     def _deserialize(self, params):
         self.EmailAddress = params.get("EmailAddress")
         self.EmailSenderName = params.get("EmailSenderName")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class CreateEmailAddressResponse(AbstractModel):
@@ -111,6 +134,13 @@ class CreateEmailIdentityRequest(AbstractModel):
 
     def _deserialize(self, params):
         self.EmailIdentity = params.get("EmailIdentity")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class CreateEmailIdentityResponse(AbstractModel):
@@ -168,6 +198,13 @@ class CreateEmailTemplateRequest(AbstractModel):
         if params.get("TemplateContent") is not None:
             self.TemplateContent = TemplateContent()
             self.TemplateContent._deserialize(params.get("TemplateContent"))
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class CreateEmailTemplateResponse(AbstractModel):
@@ -218,6 +255,13 @@ class DNSAttributes(AbstractModel):
         self.ExpectedValue = params.get("ExpectedValue")
         self.CurrentValue = params.get("CurrentValue")
         self.Status = params.get("Status")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class DeleteBlackListRequest(AbstractModel):
@@ -235,6 +279,13 @@ class DeleteBlackListRequest(AbstractModel):
 
     def _deserialize(self, params):
         self.EmailAddressList = params.get("EmailAddressList")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class DeleteBlackListResponse(AbstractModel):
@@ -269,6 +320,13 @@ class DeleteEmailAddressRequest(AbstractModel):
 
     def _deserialize(self, params):
         self.EmailAddress = params.get("EmailAddress")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class DeleteEmailAddressResponse(AbstractModel):
@@ -303,6 +361,13 @@ class DeleteEmailIdentityRequest(AbstractModel):
 
     def _deserialize(self, params):
         self.EmailIdentity = params.get("EmailIdentity")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class DeleteEmailIdentityResponse(AbstractModel):
@@ -337,6 +402,13 @@ class DeleteEmailTemplateRequest(AbstractModel):
 
     def _deserialize(self, params):
         self.TemplateID = params.get("TemplateID")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class DeleteEmailTemplateResponse(AbstractModel):
@@ -379,6 +451,13 @@ class EmailIdentity(AbstractModel):
         self.IdentityName = params.get("IdentityName")
         self.IdentityType = params.get("IdentityType")
         self.SendingEnabled = params.get("SendingEnabled")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class EmailSender(AbstractModel):
@@ -406,6 +485,13 @@ class EmailSender(AbstractModel):
         self.EmailAddress = params.get("EmailAddress")
         self.EmailSenderName = params.get("EmailSenderName")
         self.CreatedTimestamp = params.get("CreatedTimestamp")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class GetEmailIdentityRequest(AbstractModel):
@@ -423,6 +509,13 @@ class GetEmailIdentityRequest(AbstractModel):
 
     def _deserialize(self, params):
         self.EmailIdentity = params.get("EmailIdentity")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class GetEmailIdentityResponse(AbstractModel):
@@ -474,6 +567,13 @@ class GetEmailTemplateRequest(AbstractModel):
 
     def _deserialize(self, params):
         self.TemplateID = params.get("TemplateID")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class GetEmailTemplateResponse(AbstractModel):
@@ -530,6 +630,13 @@ class GetSendEmailStatusRequest(AbstractModel):
         self.Limit = params.get("Limit")
         self.MessageId = params.get("MessageId")
         self.ToEmailAddress = params.get("ToEmailAddress")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class GetSendEmailStatusResponse(AbstractModel):
@@ -585,6 +692,13 @@ class GetStatisticsReportRequest(AbstractModel):
         self.EndDate = params.get("EndDate")
         self.Domain = params.get("Domain")
         self.ReceivingMailboxType = params.get("ReceivingMailboxType")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class GetStatisticsReportResponse(AbstractModel):
@@ -654,6 +768,13 @@ class ListBlackEmailAddressRequest(AbstractModel):
         self.Offset = params.get("Offset")
         self.EmailAddress = params.get("EmailAddress")
         self.TaskID = params.get("TaskID")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class ListBlackEmailAddressResponse(AbstractModel):
@@ -770,6 +891,13 @@ class ListEmailTemplatesRequest(AbstractModel):
     def _deserialize(self, params):
         self.Limit = params.get("Limit")
         self.Offset = params.get("Offset")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class ListEmailTemplatesResponse(AbstractModel):
@@ -852,6 +980,13 @@ class SendEmailRequest(AbstractModel):
                 obj = Attachment()
                 obj._deserialize(item)
                 self.Attachments.append(obj)
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class SendEmailResponse(AbstractModel):
@@ -961,6 +1096,13 @@ class SendEmailStatus(AbstractModel):
         self.UserClicked = params.get("UserClicked")
         self.UserUnsubscribed = params.get("UserUnsubscribed")
         self.UserComplainted = params.get("UserComplainted")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class Simple(AbstractModel):
@@ -982,6 +1124,13 @@ class Simple(AbstractModel):
     def _deserialize(self, params):
         self.Html = params.get("Html")
         self.Text = params.get("Text")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class Template(AbstractModel):
@@ -1003,6 +1152,13 @@ class Template(AbstractModel):
     def _deserialize(self, params):
         self.TemplateID = params.get("TemplateID")
         self.TemplateData = params.get("TemplateData")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class TemplateContent(AbstractModel):
@@ -1024,6 +1180,13 @@ class TemplateContent(AbstractModel):
     def _deserialize(self, params):
         self.Html = params.get("Html")
         self.Text = params.get("Text")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class TemplatesMetadata(AbstractModel):
@@ -1057,6 +1220,13 @@ class TemplatesMetadata(AbstractModel):
         self.TemplateStatus = params.get("TemplateStatus")
         self.TemplateID = params.get("TemplateID")
         self.ReviewReason = params.get("ReviewReason")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class UpdateEmailIdentityRequest(AbstractModel):
@@ -1074,6 +1244,13 @@ class UpdateEmailIdentityRequest(AbstractModel):
 
     def _deserialize(self, params):
         self.EmailIdentity = params.get("EmailIdentity")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class UpdateEmailIdentityResponse(AbstractModel):
@@ -1135,6 +1312,13 @@ class UpdateEmailTemplateRequest(AbstractModel):
             self.TemplateContent._deserialize(params.get("TemplateContent"))
         self.TemplateID = params.get("TemplateID")
         self.TemplateName = params.get("TemplateName")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class UpdateEmailTemplateResponse(AbstractModel):
@@ -1198,4 +1382,11 @@ class Volume(AbstractModel):
         self.OpenedCount = params.get("OpenedCount")
         self.ClickedCount = params.get("ClickedCount")
         self.BounceCount = params.get("BounceCount")
-        self.UnsubscribeCount = params.get("UnsubscribeCount")
\ No newline at end of file
+        self.UnsubscribeCount = params.get("UnsubscribeCount")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
\ No newline at end of file
